<!-- Hi there! Here's a template for your issue - please give as many details as possible to make it easier for us to help you out-->
#### Description

<<DESCRIPTION OF THE PROBLEM>>


#### Version

- OS: [Ubuntu|MacOS|whatever]
- TorchCraft version: [master|develop|vX.X]
- StarCraft version: [openbw|windows|wine]
- Client: [python|lua|c++]


#### Reproduction guide

- <<REPRODUCTION STEPS>>

*Observed behaviour:*
<<DESCRIPTION OF THE OBSERVED BEHAVIOUR>>

*Expected behaviour:*
<<DESCRIPTION OF THE EXPECTED BEHAVIOUR>>


#### Backtrace

```
%BACKTRACE%
```
